@@ -20,16 +20,19 @@ function [fs,classid] = block(source,varargin)
 %      'dialog'
 %         shows the file dialog to choose a wav file.
 %
+%      data
+%         input data as columns of a matrix for each input channel
+%
 %      'rec'
 %         input is taken from a microphone/auxilary input;
 %
+%      {'rec','file.wav'} or {'rec','dialog'} or {'rec',data}
+%         does the same as 'rec' but plays a chosen audio data simultaneously.
+%
 %      'playrec'
 %         loopbacks the input to the output. In this case, the block size
 %         (in BLOCKREAD) cannot change during the playback.
 %
-%      data
-%         input data as columns of a matrix for each input channel
-%
 %   BLOCK accepts the following optional key-value pairs
 %
 %      'fs',fs
@@ -100,12 +103,12 @@ function [fs,classid] = block(source,varargin)
 %
 %
 %@end verbatim
-%@strong{Url}: @url{http://ltfat.sourceforge.net/doc/blockproc/block.php}
+%@strong{Url}: @url{http://ltfat.github.io/doc/blockproc/block.html}
 %@seealso{blockread, blockplay, blockana, blocksyn, demo_blockproc_basicloop, demo_blockproc_slidingsgram}
 %@end deftypefn
 
-% Copyright (C) 2005-2014 Peter L. Soendergaard <soender@users.sourceforge.net>.
-% This file is part of LTFAT version 2.0.1
+% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.1.1
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -203,6 +206,19 @@ hostAPIpriorityList = {};
 % Force portaudio to use buffer of the following size
 pa_bufLen = -1;
 
+do_recaudio = 0;
+oldsource = source;
+% Handle {'rec',...} format
+if iscell(source) && strcmpi(source{1},'rec')
+   recChannels = 1;
+   record = 1;
+   source = source{2};
+   if isempty(kv.nbuf)
+      kv.nbuf = 3;
+   end
+   do_recaudio = 1;
+end
+
 if ischar(source)
    if(strcmpi(source,'rec'))
       recChannels = 1;
@@ -210,9 +226,6 @@ if ischar(source)
       if isempty(kv.nbuf)
          kv.nbuf = 3;
       end
-      if isempty(kv.fs)
-         kv.fs = 44100;
-      end
    elseif strcmpi(source,'playrec')
       playChannels = 2;
       recChannels = 1;
@@ -221,17 +234,16 @@ if ischar(source)
       if isempty(kv.nbuf)
          kv.nbuf = 1;
       end
-      if isempty(kv.fs)
-         kv.fs = 44100;
-      end
    elseif strcmpi(source,'dialog')
       [fileName,pathName] = uigetfile('*.wav','Select the *.wav file');
       if fileName == 0
          error('%s: No file chosen.',upper(mfilename));
       end
       source = fullfile(pathName,fileName);
-      [fs,classid] = block(source,varargin{:});
-      return;
+      if isempty(kv.fs)
+          [~, kv.fs] = wavload(source, 'i');
+      end
+      play = 1;
    elseif(numel(source)>4)
       if(strcmpi(source(end-3:end),'.wav'))
          if exist(source,'file')~=2
@@ -241,16 +253,12 @@ if ischar(source)
             warning('off','Octave:fopen-file-in-path');
          end
          if isempty(kv.fs)
-            [~, kv.fs] = wavread(source, [1,1]);
+            [~, kv.fs] = wavload(source, 'i');
          end
-         playChannels = 2;
          play = 1;
       else
          error('%s: "%s" is not valid wav filename.',upper(mfilename),source);
       end
-      if isempty(kv.nbuf)
-         kv.nbuf = 3;
-      end
    else
       error('%s: Unrecognized source "%s".',upper(mfilename),source);
    end
@@ -260,15 +268,21 @@ elseif(isnumeric(source))
       warning('%s: Sampling rate not specified. Using default value %i Hz.',...
               upper(mfilename),kv.fs);
     end
-   playChannels = 2;
-   play = 1;
-   if isempty(kv.nbuf)
-      kv.nbuf = 3;
-   end
+    play = 1;
 else
    error('%s: Unrecognized source.',upper(mfilename));
 end
 
+if play && ~record
+   playChannels = 2;
+   if isempty(kv.nbuf)
+      kv.nbuf = 3;
+   end
+end
+
+if isempty(kv.fs)
+    kv.fs = 44100;
+end
 
 is_wav = ischar(source) && numel(source)>4 && strcmpi(source(end-3:end),'.wav');
 is_numeric = isnumeric(source);
@@ -319,12 +333,16 @@ block_interface('setSource',source);
 block_interface('setFs',fs);
 % Handle sources with known input length
 if is_wav
-   Ls = wavread(source, 'size');
-   tmpf = wavread(source,[1,1]); % Workaround for Octave
-   block_interface('setLs',[Ls(1),size(tmpf,2)]);
+   [~,~,~,fid] = wavload(source,'i');
+   Ls = fid(4);
+   chanNo = fid(5);
+   block_interface('setLs',[Ls,chanNo]);
    block_interface('setSource',@(pos,endSample)...
-                               cast(wavread(source,[pos, endSample]),...
+                               cast(wavload(source,'',endSample-pos+1,pos-1),...
                                block_interface('getClassId')) );
+      % block_interface('setSource',@(pos,endSample)...
+      % cast(wavread(source,[pos,endSample]),...
+      %                          block_interface('getClassId')) );
 elseif is_numeric
    source = comp_sigreshape_pre(source,'BLOCK');
    if size(source,2)>8
@@ -336,6 +354,14 @@ elseif is_numeric
                                block_interface('getClassId')));
 end
 
+% Modify the source just added to block_interface
+if do_recaudio
+    block_interface('setSource',{'rec',block_interface('getSource')});
+    % By default, we only want a single speaker to be active
+    playChannels = 1;
+end
+
+
 
 % Not a single playrec call has been done until now
 if ~flags.do_offline
@@ -448,8 +474,11 @@ if ~flags.do_offline
        catch
            failedInit(devs,kv);
        end
-       if numel(kv.recch) >1 && numel(kv.recch) ~= numel(kv.playch)
-          error('%s: Using more than one input channel.',upper(mfilename));
+       
+       if ~do_recaudio
+          if numel(kv.recch) >1 && numel(kv.recch) ~= numel(kv.playch)
+            error('%s: Using more than one input channel.',upper(mfilename));
+          end
        end
        block_interface('setPlayChanList',kv.playch);
        block_interface('setRecChanList',kv.recch);
