@@ -2,15 +2,16 @@ function definput = arg_filterbankdual(definput)
 
 definput.flags.painless = {'none','forcepainless'};
 definput.keyvals.L = [];
+
 %-*- texinfo -*-
 %@deftypefn {Function} arg_filterbankdual
 %@verbatim
 %@end verbatim
-%@strong{Url}: @url{http://ltfat.sourceforge.net/doc/comp/arg_filterbankdual.php}
+%@strong{Url}: @url{http://ltfat.github.io/doc/comp/arg_filterbankdual.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2014 Peter L. Soendergaard <soender@users.sourceforge.net>.
-% This file is part of LTFAT version 2.0.1
+% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.1.1
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -24,4 +25,4 @@ definput.keyvals.L = [];
 %
 % You should have received a copy of the GNU General Public License
 % along with this program.  If not, see <http://www.gnu.org/licenses/>.
-definput.keyvals.L = [];
+
