@@ -1,8 +1,8 @@
 function definput=arg_firwin(definput)
   
-  definput.flags.wintype={ 'hanning','hann','sine','cosine','sqrthan', ...
-                      'sqrthann','hamming', 'hammingacc','sqrtham','square','rect', ...
-                      'sqrtsquare','sqrtrect', 'tria','bartlett', ...
+  definput.flags.wintype={ 'hanning','hann','sine','cosine', ...
+                      'sqrthann','hamming', 'square','rect', ...
+                      'tria','bartlett', ...
                       'triangular','sqrttria','blackman','blackman2', ...
                       'nuttall','nuttall10','nuttall01','nuttall20', ...
                       'nuttall11','nuttall03', 'nuttall12','nuttall21', ...
@@ -14,11 +14,11 @@ function definput=arg_firwin(definput)
 %@deftypefn {Function} arg_firwin
 %@verbatim
 %@end verbatim
-%@strong{Url}: @url{http://ltfat.sourceforge.net/doc/comp/arg_firwin.php}
+%@strong{Url}: @url{http://ltfat.github.io/doc/comp/arg_firwin.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2014 Peter L. Soendergaard <soender@users.sourceforge.net>.
-% This file is part of LTFAT version 2.0.1
+% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.1.1
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
