@@ -1,14 +1,14 @@
-function foff=comp_warpedfoff(fc,bw,fs,L,scaletofreq)
+function foff=comp_warpedfoff(fc,bw,fs,L,freqtoscale,scaletofreq,do_symmetric)
 %-*- texinfo -*-
 %@deftypefn {Function} comp_warpedfoff
 %@verbatim
 %COMP_WARPEDFOFF  foff for warped filters
 %@end verbatim
-%@strong{Url}: @url{http://ltfat.sourceforge.net/doc/comp/comp_warpedfoff.php}
+%@strong{Url}: @url{http://ltfat.github.io/doc/comp/comp_warpedfoff.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2014 Peter L. Soendergaard <soender@users.sourceforge.net>.
-% This file is part of LTFAT version 2.0.1
+% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.1.1
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -23,5 +23,14 @@ function foff=comp_warpedfoff(fc,bw,fs,L,scaletofreq)
 % You should have received a copy of the GNU General Public License
 % along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-foff=floor(scaletofreq(fc-.5*bw)/fs*L)+1;
+fcwasnegative = fc < 0;
+
+if fcwasnegative && do_symmetric
+   fc = -fc;
+   fcscale = freqtoscale(fc);
+   foff = -floor(scaletofreq(fcscale+.5*bw)/fs*L)+1;
+else
+   fcscale = freqtoscale(fc);
+   foff = floor(scaletofreq(fcscale-.5*bw)/fs*L)+1;
+end
 
