@@ -4,7 +4,8 @@ if nargin<3
     callfun = mfilename;
 end
 
-if isempty(var) || ~isscalar(var) || ~isnumeric(var) || var<=0 || rem(var,1)~=0 
+if  isempty(var) || ~isscalar(var) || ~isnumeric(var) || var<=0 || ...
+        ( ~isinf(var) && rem(var,1)~=0 )
    error('%s: %s should be a positive integer.',upper(callfun),varname);
 end
 
@@ -12,11 +13,11 @@ end
 %@deftypefn {Function} complainif_notposint
 %@verbatim
 %@end verbatim
-%@strong{Url}: @url{http://ltfat.sourceforge.net/doc/comp/complainif_notposint.php}
+%@strong{Url}: @url{http://ltfat.github.io/doc/comp/complainif_notposint.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2014 Peter L. Soendergaard <soender@users.sourceforge.net>.
-% This file is part of LTFAT version 2.0.1
+% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.1.1
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
