@@ -9,12 +9,12 @@ function f=iufilterbank(varargin);
 %   with the exact same parameters as the old call to IUFILTERBANK.
 %
 %@end verbatim
-%@strong{Url}: @url{http://ltfat.sourceforge.net/doc/deprecated/iufilterbank.php}
+%@strong{Url}: @url{http://ltfat.github.io/doc/deprecated/iufilterbank.html}
 %@seealso{ifilterbank}
 %@end deftypefn
 
-% Copyright (C) 2005-2014 Peter L. Soendergaard <soender@users.sourceforge.net>.
-% This file is part of LTFAT version 2.0.1
+% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.1.1
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ function f=iufilterbank(varargin);
 % You should have received a copy of the GNU General Public License
 % along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-warning(['LTFAT: IUFILTERBANK has been deprecated, used IFILTERBANK ' ...
+warning(['LTFAT: IUFILTERBANK has been deprecated, please use IFILTERBANK ' ...
          'instead.']);
   
 
