@@ -1,26 +1,26 @@
-function framegram(F,c,varargin)
+function framegram(F,x,varargin)
 %-*- texinfo -*-
 %@deftypefn {Function} framegram
 %@verbatim
-%FRAMEGRAM  Easy visualization of energy in frame space
-%   Usage: framegram(F,c,...);
+%FRAMEGRAM  Easy visualization of energy in transform domain
+%   Usage: framegram(F,x,...);
 %
-%   FRAMEGRAM(F,c) plots the energy of the coefficients computed from
-%   the input signal x using the frame F for analysis. This is
+%   FRAMEGRAM(F,x) plots the energy of the frame coefficients computed
+%   from the input signal x using the frame F for analysis. This is
 %   just a shorthand for:
 %
-%     plotframe(F,abs(frana(F,c)).^2);
+%     plotframe(F,abs(frana(F,x)).^2);
 %
 %   Any additional arguments given to FRAMEGRAM are passed onto
 %   PLOTFRAME.
 %
 %@end verbatim
-%@strong{Url}: @url{http://ltfat.sourceforge.net/doc/frames/framegram.php}
+%@strong{Url}: @url{http://ltfat.github.io/doc/frames/framegram.html}
 %@seealso{plotframe}
 %@end deftypefn
 
-% Copyright (C) 2005-2014 Peter L. Soendergaard <soender@users.sourceforge.net>.
-% This file is part of LTFAT version 2.0.1
+% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.1.1
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -35,4 +35,5 @@ function framegram(F,c,varargin)
 % You should have received a copy of the GNU General Public License
 % along with this program.  If not, see <http://www.gnu.org/licenses/>.
     
-plotframe(F,abs(frana(F,c)).^2,varargin{:});
+plotframe(F,abs(frana(F,x)).^2,varargin{:});
+
