@@ -2,13 +2,26 @@ function a = treeSub(wt)
 %-*- texinfo -*-
 %@deftypefn {Function} treeSub
 %@verbatim
-%TREESUB
+%TREESUB  Identical subsampling factors
+%   Usage:  a = treeSub(wt)
+%
+%   Input parameters:
+%         wt  : Structure containing description of the filter tree.
+%
+%   Output parameters:
+%         a : Subsampling factors.
+%
+%   a = TREESUB(wt) returns subsampling factors asociated with the tree
+%   subbands. For definition of the structure see WFBINIT.
+%
+%
 %@end verbatim
-%@strong{Url}: @url{http://ltfat.sourceforge.net/doc/wavelets/wfbtmanip/treeSub.php}
+%@strong{Url}: @url{http://ltfat.github.io/doc/wavelets/wfbtmanip/treeSub.html}
+%@seealso{wfbtinit}
 %@end deftypefn
 
-% Copyright (C) 2005-2014 Peter L. Soendergaard <soender@users.sourceforge.net>.
-% This file is part of LTFAT version 2.0.1
+% Copyright (C) 2005-2015 Peter L. Soendergaard <peter@sonderport.dk>.
+% This file is part of LTFAT version 2.1.1
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -23,12 +36,19 @@ function a = treeSub(wt)
 % You should have received a copy of the GNU General Public License
 % along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+% Get nodes in BF order
+nodesBF = nodeBForder(0,wt);
 % All nodes with at least one final output.
-termN = find(nodesOutputsNo(1:numel(wt.nodes),wt)~=0);
+termNslice = nodesOutputsNo(nodesBF,wt)~=0;
+termN = nodesBF(termNslice);
+
 % Range in filter outputs
 outRangeTermN = nodesLocOutRange(termN,wt);
 
-cRangeTermN = nodesOutRange(termN,wt);
+%cRangeTermN = nodesOutRange(termN,wt);
+rangeOut = treeOutRange(wt);
+% Get only nodes with some output
+cRangeTermN = rangeOut(termNslice);
 
 noOut = sum(cellfun(@numel,cRangeTermN));
 % Subsampling factors of the terminal nodes
